#
# spec file for package girara
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libgirara-gtk3
%define so_ver  4
Name:           girara
Version:        0.4.4
Release:        1.4
Summary:        Graphical user interface library
License:        Zlib
URL:            https://pwmt.org/projects/girara
Source0:        %{url}/download/girara-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  gettext
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.56
BuildRequires:  pkgconfig
BuildRequires:  xvfb-run
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(pango) >= 1.14

%description
girara is a library that implements a user interface that focuses on
simplicity and minimalism. Currently based on GTK+,
it provides an interface that focuses on three main
components: A so-called view widget that represents the actual
application (e.g. a website (browser), an image (image viewer) or the
document (document viewer)), an input bar that is used to execute
commands of the application and the status bar which provides the user
with current information. girara was designed to replace and enhance
the user interface that is used by zathura and jumanji and other
features that those applications share.

%package -n %{libname}-%{so_ver}
Summary:        A graphical user interface library

%description -n %{libname}-%{so_ver}
girara is a library that implements a user interface that focuses on
simplicity and minimalism. Currently based on GTK+,
it provides an interface that focuses on three main
components: A so-called view widget that represents the actual
application (e.g. a website (browser), an image (image viewer) or the
document (document viewer)), an input bar that is used to execute
commands of the application and the status bar which provides the user
with current information. girara was designed to replace and enhance
the user interface that is used by zathura and jumanji and other
features that those applications share.

%package devel
Summary:        Header files for the girara library
Requires:       %{libname}-%{so_ver} = %{version}-%{release}

%description devel
Header files for the girara user interface library.

%prep
%autosetup

%build
export CFLAGS="%{optflags}"
%meson
%meson_build

%install
%meson_install

%find_lang %{libname}-%{so_ver}
find %{buildroot} -name '*.*a' -delete -print

%post -n %{libname}-%{so_ver} -p /sbin/ldconfig

%postun	-n %{libname}-%{so_ver} -p /sbin/ldconfig

%files -n %{libname}-%{so_ver} -f %{libname}-%{so_ver}.lang
%license LICENSE
%doc README.md
%{_libdir}/libgirara-gtk3.so.*

%files devel
%{_libdir}/libgirara-gtk3.so
%{_includedir}/girara
%{_libdir}/pkgconfig/girara-gtk3.pc

%changelog
* Thu Jun 13 2024 Joshua Smith <smolsheep@opensuse.org>
- Migrate from deprecated setup to autosetup
- Update to version 0.4.4:
  * Reduce minimum glib verson
- Updates from version 0.4.3:
  * Fix font weight mapping
  * Remove deprecated functions
  * Various fixes and improvements
* Mon Mar 25 2024 ming li <mli@suse.com>
- Update to version 0.4.2:
  * Ellipsize status bar
  * Various fixes and improvements
* Sun Dec 31 2023 Joshua Smith <jsmithfpv@gmail.com>
- update to 0.4.1:
  * Add keyboard device to simulated key events
  * Fix placement of bottom box
  * Run tests under xvfb if required
  * Rework data structures
  * Update translations
* Mon Aug 28 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.4.0
  * Fix use after free
* Sun Feb 26 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.3.9
  * Switch to json-glib
  * Add support for non-ASCII keys
* Thu Feb 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- update to 0.3.7
  * Various fixes and improvements
  * Update translations
* Wed Aug  4 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 0.3.6
  * Various fixes and improvements
  * updated translations
* Wed Jan 20 2021 Dirk Müller <dmueller@suse.com>
- update to 0.3.5
  * Set RGBA visual
  * Update translations
  * Set meson warning_level
* Tue Feb 11 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.3.4
  * bugixes
* Tue Nov  5 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.3.3
  * Various fixes and improvments
* Sat Jan 19 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.3.2
  * Various fixes and improvements
  * Update transations
* Wed May 23 2018 mimi.vx@gmail.com
- update to 0.3.0
  * Make colors changeable during runtime
  * various fixes
  * Replace deprecated GTK+ 3 functions
  * Replace build system with meson
  * Adopt CSS to newer GTK+ 3 releases
  * remove obsoleted features
* Fri Jan 26 2018 mimi.vx@gmail.com
- update to 0.2.7
- respect optflags
- spec-cleaned
  * Adopt CSS to newer GTK+ 3 releases
  * Remove obsolete features
  * Update translations
  * Various fixes and improvments
* Sun Feb  5 2017 mimi.vx@gmail.com
- update to 0.2.7
- drop girara-font-handling.patch
  * Various fixes and improvments
  * Updated font handling
* Mon Oct 17 2016 jengelh@inai.de
- Update rpm group; trim description
* Thu Oct 13 2016 mimi.vx@gmail.com
- add girara-font-handling.patch -- fix for gtk-3.21+ compaktibility
* Thu Jun  2 2016 mimi.vx@gmail.com
- update to 0.2.6
  * GTK+ 3.20 compatibility
  * Update translations
* Tue Feb 23 2016 mimi.vx@gmail.com
-  update to 0.2.5
  * Make scrollbar styleable
  * Build with C11 standard
  * Enable LFS everywhere
  * Home key mapping
  * Bind ctrl-[,j,]
  * Update translations
* Mon May 11 2015 mimi.vx@gmail.com
- edhance spec to better work with so_version
* Sun May 10 2015 mimi.vx@gmail.com
- update to 0.2.4
  * Make xembed support optional
  * Use GDK_WINDOWING_X11
  * Command to dump settings to JSON file
  * Make undershoot transparent
  * Update build system
  * Update documentation
  * Update translations
* Tue Oct 28 2014 mimi.vx@gmail.com
- change licence to Zlib
* Mon Oct 27 2014 mimi.vx@gmail.com
- move to group System/Libraries
* Fri Oct 24 2014 mimi.vx@gmail.com
- merge old changelog
* Thu Oct 23 2014 mimi.vx@gmail.com
- remove unneed deps
* Thu Oct 23 2014 mimi.vx@gmail.com
- rename giara-devel
* Thu Oct 23 2014 mimi.vx@gmail.com
- remove check
- add SONAME
* Thu Oct 23 2014 mimi.vx@gmail.com
- add ncurses-utils to deps
* Thu Oct 23 2014 mimi.vx@gmail.com
- move to pkg-config
- add check
* Thu Oct 23 2014 mimi.vx@gmail.com
- update to 0.23 upstream version
* Sat May 12 2012 seiler@b1-systems.de
- removed outcommented lines
- changed lang package name to follow SUSE guidelines
- added rpm optflags...RPM guidelines
* Thu Apr 26 2012 seiler@b1-systems.de
- enhanced Summary of libgirara to increase the chance to get this thing upstream
* Wed Apr 25 2012 seiler@b1-systems.de
- changed wrong dependency because of this error
  unresolvable: nothing provides girara = 0.1.2 needed by girara-devel
* Wed Apr 25 2012 seiler@b1-systems.de
- initial commit
